@@ -14,8 +14,6 @@ class Notifications(Client):
     """
     :link: https://github.com/amzn/selling-partner-api-docs/blob/main/references/notifications-api/notifications.md
     """
-    def __init__(self, marketplace=Marketplaces.US, *, refresh_token=None, account='default', credentials=None):
-        super().__init__(marketplace, refresh_token, account, credentials)
 
     @deprecated
     def add_subscription(self, notification_type: NotificationType or str, **kwargs):
